@@ -3,6 +3,9 @@
 import getopt
 import sys
 
+from bin import util
+util.strip_syspath_locals()
+
 import os
 import glob
 import gettext
@@ -70,28 +73,29 @@ CATEGORIES = [
 CONTROL_CENTER_MODULES = [
     #         Label                              Module ID                Icon                         Category      Keywords for filter
     [_("Network"),                          "network",            "cs-network",                 "hardware",      _("network, wireless, wifi, ethernet, broadband, internet")],
-    [_("Display"),                          "display",            "cs-display",                 "hardware",      _("display, screen, monitor, layout, resolution, dual, lcd")],
     [_("Color"),                            "color",              "cs-color",                   "hardware",      _("color, profile, display, printer, output")],
     [_("Graphics Tablet"),                  "wacom",              "cs-tablet",                  "hardware",      _("wacom, digitize, tablet, graphics, calibrate, stylus")]
 ]
 
 STANDALONE_MODULES = [
-    #         Label                          Executable                          Icon                Category        Keywords for filter
-    [_("Printers"),                      "system-config-printer",               "cs-printer",         "hardware",       _("printers, laser, inkjet")],
-    [_("Firewall"),                      "gufw",                                "cs-firewall",        "admin",          _("firewall, block, filter, programs")],
-    [_("Firewall"),                      "firewall-config",                     "cs-firewall",        "admin",          _("firewall, block, filter, programs")],
-    [_("Languages"),                     "mintlocale",                          "cs-language",        "prefs",          _("language, install, foreign")],
-    [_("Input Method"),                  "mintlocale-im",                       "cs-input-method",    "prefs",          _("language, install, foreign, input, method, chinese, korean, japanese, typing")],
-    [_("Login Window"),                  "pkexec lightdm-settings",             "cs-login",           "admin",          _("login, lightdm, mdm, gdm, manager, user, password, startup, switch")],
-    [_("Login Window"),                  "lightdm-gtk-greeter-settings-pkexec", "cs-login",           "admin",          _("login, lightdm, manager, settings, editor")],
-    [_("Driver Manager"),                "pkexec driver-manager",               "cs-drivers",         "admin",          _("video, driver, wifi, card, hardware, proprietary, nvidia, radeon, nouveau, fglrx")],
-    [_("Nvidia Settings"),               "nvidia-settings",                     "cs-drivers",         "admin",          _("video, driver, proprietary, nvidia, settings")],
-    [_("Software Sources"),              "pkexec mintsources",                  "cs-sources",         "admin",          _("ppa, repository, package, source, download")],
-    [_("Package Management"),            "dnfdragora",                          "cs-sources",         "admin",          _("update, install, repository, package, source, download")],
-    [_("Package Management"),            "yumex-dnf",                           "cs-sources",         "admin",          _("update, install, repository, package, source, download")],
-    [_("Users and Groups"),              "cinnamon-settings-users",             "cs-user-accounts",   "admin",          _("user, users, account, accounts, group, groups, password")],
-    [_("Bluetooth"),                     "blueberry",                           "cs-bluetooth",       "hardware",       _("bluetooth, dongle, transfer, mobile")],
-    [_("Manage Services and Units"),     "systemd-manager-pkexec",              "cs-sources",         "admin",          _("systemd, units, services, systemctl, init")]
+    # Label                              Executable                             Icon                     Category          Keywords for filter
+    [_("Printers"),                      "system-config-printer",               "cs-printer",            "hardware",       _("printers, laser, inkjet")],
+    [_("Firewall"),                      "gufw",                                "cs-firewall",           "admin",          _("firewall, block, filter, programs")],
+    [_("Firewall"),                      "firewall-config",                     "cs-firewall",           "admin",          _("firewall, block, filter, programs")],
+    [_("Languages"),                     "mintlocale",                          "cs-language",           "prefs",          _("language, install, foreign")],
+    [_("Input Method"),                  "mintlocale-im",                       "cs-input-method",       "prefs",          _("language, install, foreign, input, method, chinese, korean, japanese, typing")],
+    [_("Login Window"),                  "pkexec lightdm-settings",             "cs-login",              "admin",          _("login, lightdm, mdm, gdm, manager, user, password, startup, switch")],
+    [_("Login Window"),                  "lightdm-gtk-greeter-settings-pkexec", "cs-login",              "admin",          _("login, lightdm, manager, settings, editor")],
+    [_("Driver Manager"),                "pkexec driver-manager",               "cs-drivers",            "admin",          _("video, driver, wifi, card, hardware, proprietary, nvidia, radeon, nouveau, fglrx")],
+    [_("Nvidia Settings"),               "nvidia-settings",                     "cs-drivers",            "admin",          _("video, driver, proprietary, nvidia, settings")],
+    [_("Software Sources"),              "pkexec mintsources",                  "cs-sources",            "admin",          _("ppa, repository, package, source, download")],
+    [_("Package Management"),            "dnfdragora",                          "cs-sources",            "admin",          _("update, install, repository, package, source, download")],
+    [_("Package Management"),            "yumex-dnf",                           "cs-sources",            "admin",          _("update, install, repository, package, source, download")],
+    [_("Users and Groups"),              "cinnamon-settings-users",             "cs-user-accounts",      "admin",          _("user, users, account, accounts, group, groups, password")],
+    [_("Bluetooth"),                     "blueberry",                           "cs-bluetooth",          "hardware",       _("bluetooth, dongle, transfer, mobile")],
+    [_("Blueman"),                       "blueman-manager",                     "cs-bluetooth",          "hardware",       _("bluetooth, dongle, transfer, mobile")],
+    [_("Manage Services and Units"),     "systemd-manager-pkexec",              "cs-sources",            "admin",          _("systemd, units, services, systemctl, init")],
+    [_("Disks"),                         "gnome-disks",                         "org.gnome.DiskUtility", "hardware",       _("disks, manage, hardware, management, hard, hdd, pendrive, format, erase, test, create, iso, ISO, disk, image")]
 ]
 
 TABS = {
@@ -101,6 +105,7 @@ TABS = {
     "backgrounds":      {"images": 0, "settings": 1},
     "default":          {"preferred": 0, "removable": 1},
     "desklets":         {"installed": 0, "more": 1, "download": 1, "general": 2},
+    "display":          {"layout": 0, "settings": 1},
     "effects":          {"effects": 0, "customize": 1},
     "extensions":       {"installed": 0, "more": 1, "download": 1},
     "keyboard":         {"typing": 0, "shortcuts": 1, "layouts": 2},
@@ -144,6 +149,7 @@ ARG_REWRITE = {
     'users':            'cinnamon-settings-users'
 }
 
+
 def print_timing(func):
     # decorate functions with @print_timing to output how long they take to run.
     def wrapper(*arg):
@@ -154,12 +160,13 @@ def print_timing(func):
         return res
     return wrapper
 
+
 def touch(fname, times=None):
-    with file(fname, 'a'):
+    with open(fname, 'a'):
         os.utime(fname, times)
 
-class MainWindow:
 
+class MainWindow:
     # Change pages
     def side_view_nav(self, side_view, path, cat):
         selected_items = side_view.get_selected_items()
@@ -177,14 +184,13 @@ class MainWindow:
 
     def go_to_sidepage(self, cat, path, user_action=True):
         iterator = self.store[cat].get_iter(path)
-        sidePage = self.store[cat].get_value(iterator,2)
+        sidePage = self.store[cat].get_value(iterator, 2)
         if not sidePage.is_standalone:
             if not user_action:
                 self.window.set_title(sidePage.name)
                 self.window.set_icon_name(sidePage.icon)
             sidePage.build()
             if sidePage.stack:
-                current_page = sidePage.stack.get_visible_child_name()
                 self.stack_switcher.set_stack(sidePage.stack)
                 l = sidePage.stack.get_children()
                 if len(l) > 0:
@@ -193,7 +199,7 @@ class MainWindow:
                         visible_child = sidePage.stack.get_visible_child()
                         if self.tab == 1 \
                         and hasattr(visible_child, 'sort_combo') \
-                        and self.sort in range(4):
+                        and self.sort in range(5):
                             visible_child.sort_combo.set_active(self.sort)
                             visible_child.sort_changed()
                     else:
@@ -209,6 +215,7 @@ class MainWindow:
                     self.stack_switcher.set_opacity(0)
             else:
                 self.stack_switcher.set_opacity(0)
+
             if user_action:
                 self.main_stack.set_visible_child_name("content_box_page")
                 self.header_stack.set_visible_child_name("content_box")
@@ -251,9 +258,10 @@ class MainWindow:
             if key is not cat:
                 self.side_view[key].unselect_all()
 
-    ''' Create the UI '''
+    # Create the UI
     def __init__(self):
         self.builder = Gtk.Builder()
+        self.builder.set_translation_domain('cinnamon')  # let it translate!
         self.builder.add_from_file(config.currentPath + "/cinnamon-settings.ui")
         self.window = XApp.GtkWindow(window_position=Gtk.WindowPosition.CENTER,
                                      default_width=800, default_height=600)
@@ -324,10 +332,9 @@ class MainWindow:
         # sort the modules alphabetically according to the current locale
         localeStrKey = cmp_to_key(locale.strcoll)
         # Apply locale key to the field name of each side page.
-        sidePagesKey = lambda m : localeStrKey(m[0].name)
+        sidePagesKey = lambda m: localeStrKey(m[0].name)
         self.sidePages = sorted(self.unsortedSidePages, key=sidePagesKey)
 
-
         # create the backing stores for the side nav-view.
         sidePagesIters = {}
         self.store = {}
@@ -373,8 +380,8 @@ class MainWindow:
 
         self.calculate_bar_heights()
 
-        self.tab = 0 # open 'manage' tab by default
-        self.sort = 1 # sorted by 'score' by default
+        self.tab = 0  # open 'manage' tab by default
+        self.sort = 1  # sorted by 'score' by default
 
         # Select the first sidePage
         if len(sys.argv) > 1:
@@ -393,7 +400,7 @@ class MainWindow:
             #   cinnamon-settings.py desklets -t 2
             # Please note that useless or wrong arguments are ignored.
             opts = []
-            sorts_literal = {"name":0, "score":1, "date":2, "installed":3}
+            sorts_literal = {"name":0, "score":1, "date":2, "installed":3, "update":4}
             tabs_literal = {"default":0}
             if arg1 in TABS.keys():
                 tabs_literal = TABS[arg1]
@@ -427,8 +434,7 @@ class MainWindow:
             if path:
                 self.go_to_sidepage(cat, path, user_action=False)
                 self.window.show()
-                if arg1 in ("mintlocale", "blueberry", "system-config-printer", \
-                            "mintlocale-im", "nvidia-settings"):
+                if arg1 in ("mintlocale", "blueberry", "system-config-printer", "mintlocale-im", "nvidia-settings"):
                     # These modules do not need to leave the System Settings window open,
                     # when selected by command line argument.
                     self.window.close()
@@ -624,7 +630,6 @@ class MainWindow:
     def on_keynav_failed(self, widget, direction, category):
         num_cats = len(CATEGORIES)
         current_idx = self.get_cur_cat_index(category)
-        new_cat = CATEGORIES[current_idx]
         ret = False
         dist = 1000
         sel = None
@@ -692,7 +697,7 @@ class MainWindow:
 
     def back_to_icon_view(self, widget):
         self.window.set_title(_("System Settings"))
-        self.window.set_icon_name("preferences-system")
+        self.window.set_icon_name("preferences-desktop")
         self.window.resize(WIN_WIDTH, WIN_HEIGHT)
         children = self.content_box.get_children()
         for child in children:
@@ -704,12 +709,17 @@ class MainWindow:
         self.main_stack.set_visible_child_name("side_view_page")
         self.header_stack.set_visible_child_name("side_view")
         self.search_entry.grab_focus()
+
+        if self.current_sidepage.module and hasattr(self.current_sidepage.module, "on_navigate_out_of_module"):
+            self.current_sidepage.module.on_navigate_out_of_module()
+
         self.current_sidepage = None
 
     def quit(self, *args):
         self.window.destroy()
         Gtk.main_quit()
 
+
 if __name__ == "__main__":
     setproctitle("cinnamon-settings")
     import signal
@@ -722,5 +732,5 @@ if __name__ == "__main__":
     urllib.install_opener(urllib.build_opener(proxy))
 
     window = MainWindow()
-    signal.signal(signal.SIGINT, window.quit)
+    signal.signal(signal.SIGINT, signal.SIG_DFL)
     Gtk.main()
